# meetbot messages

A schema package for [meetbot](http://github.com/fedora-infra/meetbot-messages).

See the [detailed documentation](https://fedora-messaging.readthedocs.io/en/latest/messages.html) on packaging your schemas.
